@@ -16,24 +16,29 @@
 
 package org.gradle.api.internal.tasks;
 
-import org.gradle.api.internal.changedetection.state.FileCollectionSnapshotter;
-import org.gradle.api.internal.changedetection.state.GenericFileCollectionSnapshotter;
-import org.gradle.api.internal.changedetection.state.SnapshotNormalizationStrategy;
-import org.gradle.api.internal.changedetection.state.TaskFilePropertySnapshotNormalizationStrategy;
-import org.gradle.api.tasks.PathSensitivity;
+import org.gradle.api.NonNullApi;
+import org.gradle.api.tasks.FileNormalizer;
 import org.gradle.api.tasks.TaskOutputFilePropertyBuilder;
+import org.gradle.internal.fingerprint.OutputNormalizer;
 
-abstract class AbstractTaskOutputPropertySpec extends AbstractTaskOutputsDeprecatingTaskPropertyBuilder implements TaskOutputPropertySpecAndBuilder {
+@NonNullApi
+abstract class AbstractTaskOutputPropertySpec extends TaskOutputsDeprecationSupport implements TaskPropertySpec, TaskOutputFilePropertyBuilder {
+
+    private String propertyName;
     private boolean optional;
-    private SnapshotNormalizationStrategy snapshotNormalizationStrategy = TaskFilePropertySnapshotNormalizationStrategy.ABSOLUTE;
 
     @Override
     public TaskOutputFilePropertyBuilder withPropertyName(String propertyName) {
-        setPropertyName(propertyName);
+        this.propertyName = TaskPropertyUtils.checkPropertyName(propertyName);
         return this;
     }
 
-    public boolean isOptional() {
+    @Override
+    public String getPropertyName() {
+        return propertyName;
+    }
+
+    protected boolean isOptional() {
         return optional;
     }
 
@@ -48,23 +53,13 @@ abstract class AbstractTaskOutputPropertySpec extends AbstractTaskOutputsDepreca
         return this;
     }
 
-    public SnapshotNormalizationStrategy getSnapshotNormalizationStrategy() {
-        return snapshotNormalizationStrategy;
-    }
-
-    @Override
-    public TaskOutputFilePropertyBuilder withPathSensitivity(PathSensitivity sensitivity) {
-        this.snapshotNormalizationStrategy = TaskFilePropertySnapshotNormalizationStrategy.valueOf(sensitivity);
-        return this;
-    }
-
     @Override
     public String toString() {
-        return getPropertyName() + " (" + snapshotNormalizationStrategy + ")";
+        return getPropertyName() + " (Output)";
     }
 
-    public Class<? extends FileCollectionSnapshotter> getSnapshotter() {
-        return GenericFileCollectionSnapshotter.class;
+    public Class<? extends FileNormalizer> getNormalizer() {
+        return OutputNormalizer.class;
     }
 
     @Override
