@@ -25,14 +25,19 @@ import org.gradle.api.Action;
 import org.gradle.api.GradleException;
 import org.gradle.api.internal.ClosureBackedAction;
 import org.gradle.internal.Actions;
-import org.gradle.model.internal.core.*;
+import org.gradle.internal.MutableBoolean;
+import org.gradle.model.internal.core.ModelActionRole;
+import org.gradle.model.internal.core.ModelPath;
+import org.gradle.model.internal.core.ModelReference;
+import org.gradle.model.internal.core.ModelRegistrations;
+import org.gradle.model.internal.core.NoInputsModelAction;
+import org.gradle.model.internal.core.NodeInitializer;
+import org.gradle.model.internal.core.NodeInitializerRegistry;
 import org.gradle.model.internal.core.rule.describe.ModelRuleDescriptor;
 import org.gradle.model.internal.core.rule.describe.SimpleModelRuleDescriptor;
 import org.gradle.model.internal.registry.ModelRegistry;
 import org.gradle.model.internal.type.ModelType;
 
-import java.util.concurrent.atomic.AtomicBoolean;
-
 import static org.gradle.model.internal.core.DefaultNodeInitializerRegistry.DEFAULT_REFERENCE;
 import static org.gradle.model.internal.core.NodeInitializerContext.forType;
 
@@ -44,13 +49,13 @@ public class NonTransformedModelDslBacking extends GroovyObjectSupport {
 
     private final ModelPath modelPath;
     private final ModelRegistry modelRegistry;
-    private AtomicBoolean executingDsl;
+    private final MutableBoolean executingDsl;
 
     public NonTransformedModelDslBacking(ModelRegistry modelRegistry) {
-        this(new AtomicBoolean(), null, modelRegistry);
+        this(new MutableBoolean(), null, modelRegistry);
     }
 
-    private NonTransformedModelDslBacking(AtomicBoolean executingDsl, ModelPath modelPath, ModelRegistry modelRegistry) {
+    private NonTransformedModelDslBacking(MutableBoolean executingDsl, ModelPath modelPath, ModelRegistry modelRegistry) {
         this.executingDsl = executingDsl;
         this.modelPath = modelPath;
         this.modelRegistry = modelRegistry;
@@ -89,7 +94,7 @@ public class NonTransformedModelDslBacking extends GroovyObjectSupport {
     public void configure(Closure<?> action) {
         executingDsl.set(true);
         try {
-            new ClosureBackedAction<Object>(action).execute(this);
+            ClosureBackedAction.execute(this, action);
         } finally {
             executingDsl.set(false);
         }
