@@ -16,42 +16,39 @@
 
 package org.gradle.tooling.internal.consumer.connection;
 
-import org.gradle.api.Action;
 import org.gradle.tooling.internal.adapter.ViewBuilder;
-import org.gradle.tooling.internal.connection.DefaultProjectIdentifier;
 import org.gradle.tooling.internal.consumer.converters.BasicGradleProjectIdentifierMixin;
 import org.gradle.tooling.internal.consumer.converters.FixedBuildIdentifierProvider;
 import org.gradle.tooling.internal.consumer.converters.GradleProjectIdentifierMixin;
-import org.gradle.tooling.internal.consumer.converters.IdeaModelCompatibilityMapping;
-import org.gradle.tooling.internal.consumer.converters.TaskDisplayNameCompatibilityMapping;
+import org.gradle.tooling.internal.consumer.converters.IdeaModuleDependencyTargetNameMixin;
+import org.gradle.tooling.internal.consumer.converters.IdeaProjectJavaLanguageSettingsMixin;
+import org.gradle.tooling.internal.consumer.converters.IncludedBuildsMixin;
+import org.gradle.tooling.internal.consumer.converters.TaskDisplayNameMixin;
 import org.gradle.tooling.internal.consumer.parameters.ConsumerOperationParameters;
-import org.gradle.tooling.internal.consumer.versioning.VersionDetails;
+import org.gradle.tooling.internal.gradle.DefaultProjectIdentifier;
 import org.gradle.tooling.model.GradleProject;
-import org.gradle.tooling.model.ProjectIdentifier;
+import org.gradle.tooling.model.GradleTask;
 import org.gradle.tooling.model.gradle.BasicGradleProject;
+import org.gradle.tooling.model.gradle.GradleBuild;
+import org.gradle.tooling.model.idea.IdeaDependency;
+import org.gradle.tooling.model.idea.IdeaProject;
 
 public class HasCompatibilityMapping {
 
-    private final Action<ViewBuilder<?>> taskPropertyHandlerMapper;
-    private final Action<ViewBuilder<?>> ideaProjectCompatibilityMapper;
-
-    public HasCompatibilityMapping(VersionDetails versionDetails) {
-        taskPropertyHandlerMapper = new TaskDisplayNameCompatibilityMapping(versionDetails);
-        ideaProjectCompatibilityMapper = new IdeaModelCompatibilityMapping(versionDetails);
-    }
-
     public <T> ViewBuilder<T> applyCompatibilityMapping(ViewBuilder<T> viewBuilder, ConsumerOperationParameters parameters) {
-        ProjectIdentifier projectIdentifier = new DefaultProjectIdentifier(parameters.getBuildIdentifier(), ":");
+        DefaultProjectIdentifier projectIdentifier = new DefaultProjectIdentifier(parameters.getProjectDir(), ":");
         return applyCompatibilityMapping(viewBuilder, projectIdentifier);
     }
 
-    public <T> ViewBuilder<T> applyCompatibilityMapping(ViewBuilder<T> viewBuilder, ProjectIdentifier projectIdentifier) {
+    public <T> ViewBuilder<T> applyCompatibilityMapping(ViewBuilder<T> viewBuilder, DefaultProjectIdentifier projectIdentifier) {
         viewBuilder.mixInTo(GradleProject.class, new GradleProjectIdentifierMixin(projectIdentifier.getBuildIdentifier()));
         viewBuilder.mixInTo(BasicGradleProject.class, new BasicGradleProjectIdentifierMixin(projectIdentifier.getBuildIdentifier()));
         FixedBuildIdentifierProvider identifierProvider = new FixedBuildIdentifierProvider(projectIdentifier);
         identifierProvider.applyTo(viewBuilder);
-        taskPropertyHandlerMapper.execute(viewBuilder);
-        ideaProjectCompatibilityMapper.execute(viewBuilder);
+        viewBuilder.mixInTo(GradleTask.class, TaskDisplayNameMixin.class);
+        viewBuilder.mixInTo(IdeaProject.class, IdeaProjectJavaLanguageSettingsMixin.class);
+        viewBuilder.mixInTo(IdeaDependency.class, IdeaModuleDependencyTargetNameMixin.class);
+        viewBuilder.mixInTo(GradleBuild.class, IncludedBuildsMixin.class);
         return viewBuilder;
     }
 }
